@@ -34,7 +34,7 @@ class ECCPrivateKey(base.BasePrivateKey):
         self,
         encoding: str = "PEM",
         format: str = "PKCS8",
-        passphrase: typing.Optional[typing.ByteString] = None,
+        passphrase: typing.Optional[bytes] = None,
         *,
         protection: typing.Optional[str] = None,
     ) -> bytes:
@@ -106,7 +106,9 @@ class ECCPrivateKey(base.BasePrivateKey):
             return key
         return key.encode("utf-8")
 
-    def signer(self, *, mode: str = "fips-186-3", encoding: str = "binary"):
+    def signer(
+        self, *, mode: str = "fips-186-3", encoding: str = "binary"
+    ) -> _SigVerContext:
         """Create a signer context.
 
         Keyword Arguments:
@@ -129,7 +131,7 @@ class ECCPrivateKey(base.BasePrivateKey):
         """
         return _SigVerContext(True, get_DSS(self._key, mode, encoding))
 
-    def exchange(self, peer_public_key: typing.ByteString) -> bytes:
+    def exchange(self, peer_public_key: bytes) -> bytes:
         raise NotImplementedError(
             "key exchange is currently not supported by the backend."
         )
@@ -137,9 +139,9 @@ class ECCPrivateKey(base.BasePrivateKey):
     @classmethod
     def load(
         cls,
-        data: typing.ByteString,
-        passphrase: typing.Optional[typing.ByteString] = None,
-    ):
+        data: bytes,
+        passphrase: typing.Optional[bytes] = None,
+    ) -> ECCPrivateKey:
         """Loads the private key as binary object and returns the Key
         interface.
 
@@ -175,7 +177,9 @@ class ECCPublicKey(base.BasePublicKey):
     def __init__(self, key):
         self._key = key
 
-    def serialize(self, encoding: str = "PEM", *, compress: bool = False):
+    def serialize(
+        self, encoding: str = "PEM", *, compress: bool = False
+    ) -> bytes:
         """Serialize the private key.
 
         Args:
@@ -204,7 +208,9 @@ class ECCPublicKey(base.BasePublicKey):
             return key
         return key.encode()
 
-    def verifier(self, *, mode: str = "fips-186-3", encoding: str = "binary"):
+    def verifier(
+        self, *, mode: str = "fips-186-3", encoding: str = "binary"
+    ) -> _SigVerContext:
         """Create a DSS verifier context.
 
         Args:
@@ -228,7 +234,7 @@ class ECCPublicKey(base.BasePublicKey):
         return _SigVerContext(False, get_DSS(self._key, mode, encoding))
 
     @classmethod
-    def load(cls, data: typing.ByteString):
+    def load(cls, data: bytes) -> ECCPublicKey:
         """Loads the public key as binary object and returns the Key object.
 
         Args:
@@ -317,7 +323,7 @@ def generate(curve: str) -> ECCPrivateKey:
     return ECCPrivateKey(curve)
 
 
-def load_public_key(data: typing.ByteString):
+def load_public_key(data: bytes) -> ECCPublicKey:
     """Loads the public key and returns a Key interface.
 
     Args:
@@ -331,8 +337,8 @@ def load_public_key(data: typing.ByteString):
 
 
 def load_private_key(
-    data: typing.ByteString,
-    passphrase: typing.Optional[typing.ByteString] = None,
+    data: bytes,
+    passphrase: typing.Optional[bytes] = None,
 ) -> ECCPrivateKey:
     """Loads the private key and returns a Key interface.
 
