@@ -268,20 +268,21 @@ class _EAX:
         return self.__tag
 
 
-def strxor(x: typing.ByteString, y: typing.ByteString) -> bytes:
+def strxor(x: bytes, y: bytes) -> bytes:
     """XOR two byte strings"""
     return bytes([ix ^ iy for ix, iy in zip(x, y)])
 
 
 def new(
     encrypting: bool,
-    key: typing.ByteString,
+    key: bytes,
     mode: _m,
-    iv_or_nonce: typing.ByteString,
+    iv_or_nonce: bytes,
     *,
-    file: typing.Optional[typing.BinaryIO] = None,
     use_hmac: bool = False,
-    digestmod: [str, base.BaseHash] = "sha256",
+    tag_length: typing.Optional[int] = 16,
+    digestmod: typing.Union[str, base.BaseHash] = "sha256",
+    file: typing.Optional[typing.BinaryIO] = None,
 ) -> typing.Union[AEAD, NonAEAD, FileCipherWrapper, HMACWrapper]:
     """Create a new backend specific AES cipher.
 
@@ -297,21 +298,26 @@ def new(
             repeated with the same key.
 
     Keyword Arguments:
-        file (filelike):
-            The source file to read from. If `file` is specified
-            and the `mode` is not an AEAD mode, HMAC is always used.
         use_hmac (bool):
-            Should the cipher use HMAC as authentication or not,
-            if it does not support AEAD. (Default: False)
+            Should the cipher use HMAC as authentication or not, if it does not
+            support AEAD. (Default: False)
+        tag_length (int, None):
+            Length of HMAC tag. By default, a **16 byte tag** is generated. If
+            ``tag_length`` is ``None``, a **non-truncated** tag is generated.
+            Length of non-truncated tag depends on the digest size of the
+            underlying hash algorithm used by HMAC.
         digestmod (str, BaseHash):
-            The algorithm to use for HMAC. Defaults to ``sha256``.
-            Specifying this value without setting ``use_hmac`` to True
-            has no effect.
+            The algorithm to use for HMAC. Defaults to ``sha256``. Specifying
+            this value without setting ``use_hmac`` to True has no effect.
+        file (filelike):
+            The source file to read from. If `file` is specified and the `mode`
+            is not an AEAD mode, HMAC is always used.
 
     Important:
         The following arguments are ignored if the mode is an AEAD mode:
 
         - ``use_hmac``
+        - ``tag_length``
         - ``digestmod``
 
     Returns:
@@ -339,7 +345,14 @@ def new(
         crp = AEAD(encrypting, key, mode, iv_or_nonce)
     else:
         if use_hmac:
-            crp = _wrap_hmac(encrypting, key, mode, iv_or_nonce, digestmod)
+            crp = _wrap_hmac(
+                encrypting,
+                key,
+                mode,
+                iv_or_nonce,
+                digestmod,
+                tag_length,
+            )
         else:
             crp = NonAEAD(encrypting, key, mode, iv_or_nonce)
 
@@ -372,13 +385,14 @@ def _aes_cipher(key, mode, nonce_or_iv):
     return CrCipher(algo.AES(key), SUPPORTED[mode](nonce_or_iv), defb())
 
 
-def _wrap_hmac(encrypting, key, mode, iv_or_nonce, digestmod):
+def _wrap_hmac(encrypting, key, mode, iv_or_nonce, digestmod, tag_length):
     ckey, hkey = derive_hkdf_key(key, len(key), digestmod, iv_or_nonce)
     crp = HMACWrapper(
         NonAEAD(encrypting, ckey, mode, iv_or_nonce),
         hkey,
         iv_or_nonce,
         digestmod,
+        tag_length=tag_length,
         offset=15,
     )
     return crp
