@@ -38,6 +38,8 @@ _supported_encodings = frozenset(
 
 
 class _RSANumbers:
+    _key: typing.Union[rsa.RSAPrivateKey, rsa.RSAPublicKey]
+
     def _numbers(self):
         try:
             k = self._key.public_numbers()
@@ -127,7 +129,7 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
         self,
         encoding: str = "PEM",
         format: str = "PKCS8",
-        passphrase: typing.Optional[typing.ByteString] = None,
+        passphrase: typing.Optional[bytes] = None,
     ) -> bytes:
         """Serialize the private key.
 
@@ -170,9 +172,9 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
     @classmethod
     def load(
         cls,
-        data: typing.ByteString,
-        passphrase: typing.Optional[typing.ByteString] = None,
-    ):
+        data: bytes,
+        passphrase: typing.Optional[bytes] = None,
+    ) -> RSAPrivateKey:
         """Loads the private key as ``bytes`` object and returns
         the Key interface.
 
@@ -180,9 +182,9 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
             data (bytes, bytearray):
                 The key as bytes object.
             passphrase (bytes, bytearray):
-                The passphrase that deserializes the private key. ``passphrase``
-                must be a ``bytes-like`` object if the key was encrypted while
-                serialization, otherwise ``None``.
+                The passphrase that deserializes the private key.
+                ``passphrase`` must be a ``bytes-like`` object if the key was
+                encrypted while serialization, otherwise ``None``.
 
         Returns:
             RSAPrivateKey: RSA private key.
@@ -209,7 +211,7 @@ class RSAPrivateKey(_RSANumbers, base.BasePrivateKey):
             key = loader(memoryview(data), passphrase, defb())
             if not isinstance(key, rsa.RSAPrivateKey):
                 raise ValueError("The key is not an RSA private key.")
-            return cls(0, key=key)
+            return cls(None, key=key)
         except ValueError as e:
             raise ValueError(
                 "Cannot deserialize key. Either Key format is invalid or "
@@ -244,7 +246,7 @@ class RSAPublicKey(_RSANumbers, base.BasePublicKey):
             False, self._key, get_padding_func(padding)(padding)
         )
 
-    def verifier(self, padding=PSS()) -> _EncDecContext:
+    def verifier(self, padding=PSS()) -> _SigVerContext:
         """Creates a verifier context.
 
         Args:
@@ -286,7 +288,7 @@ class RSAPublicKey(_RSANumbers, base.BasePublicKey):
         return self._key.public_bytes(encd, fmt)
 
     @classmethod
-    def load(cls, data: typing.ByteString) -> RSAPublicKey:
+    def load(cls, data: bytes) -> RSAPublicKey:
         """Loads the public key as ``bytes`` object and returns
         the Key interface.
 
@@ -438,7 +440,7 @@ def generate(bits: int, e: int = 65537) -> RSAPrivateKey:
     return RSAPrivateKey(bits, e)
 
 
-def load_public_key(data: typing.ByteString) -> RSAPublicKey:
+def load_public_key(data: bytes) -> RSAPublicKey:
     """Loads the public key and returns a Key interface.
 
     Args:
@@ -452,8 +454,8 @@ def load_public_key(data: typing.ByteString) -> RSAPublicKey:
 
 
 def load_private_key(
-    data: typing.ByteString,
-    passphrase: typing.Optional[typing.ByteString] = None,
+    data: bytes,
+    passphrase: typing.Optional[bytes] = None,
 ) -> RSAPrivateKey:
     """Loads the private key and returns a Key interface.
 
