@@ -18,7 +18,7 @@ class BaseSymmetricCipher(metaclass=ABCMeta):
         """
 
     @abstractmethod
-    def update(self, data: typing.ByteString) -> bytes:
+    def update(self, data: bytes) -> bytes:
         """Takes bytes-like object and returns encrypted/decrypted
         bytes object.
 
@@ -33,8 +33,8 @@ class BaseSymmetricCipher(metaclass=ABCMeta):
     @abstractmethod
     def update_into(
         self,
-        data: typing.ByteString,
-        out: typing.ByteString,
+        data: bytes,
+        out: bytes,
     ) -> None:
         """Encrypt or decrypt the `data` and store it in a preallocated buffer
         `out`.
@@ -70,14 +70,14 @@ class BaseNonAEADCipher(BaseSymmetricCipher):
 class BaseAEADCipher(BaseSymmetricCipher):
     """Abstract base class for AEAD ciphers.
 
-    Custom cipher wrappers that provide AEAD functionality to NonAEAD
-    ciphers must derive from this.
+    Custom cipher wrappers that provide AEAD functionality to NonAEAD ciphers
+    must derive from this.
     """
 
     __slots__ = ()
 
     @abstractmethod
-    def authenticate(self, data: typing.ByteString) -> None:
+    def authenticate(self, data: bytes) -> None:
         """Authenticates part of the message that get delivered as is, without
         any encryption.
 
@@ -92,7 +92,7 @@ class BaseAEADCipher(BaseSymmetricCipher):
         """
 
     @abstractmethod
-    def finalize(self, tag: typing.Optional[typing.ByteString] = None) -> None:
+    def finalize(self, tag: typing.Optional[bytes] = None) -> None:
         """Finalizes and ends the cipher state.
 
         Args:
@@ -129,8 +129,8 @@ class BaseHash(metaclass=ABCMeta):
     def digest_size(self) -> int:
         """
         The size of the digest produced by the hashing object, measured in
-        bytes. If the hash has a variable output size, this output size must
-        be chosen when the hashing object is created, and this attribute must
+        bytes. If the hash has a variable output size, this output size must be
+        chosen when the hashing object is created, and this attribute must
         contain the selected size. Therefore, None is not a legal value for
         this attribute.
 
@@ -159,7 +159,7 @@ class BaseHash(metaclass=ABCMeta):
         """
 
     @abstractmethod
-    def update(self, data: typing.ByteString) -> None:
+    def update(self, data: bytes) -> None:
         """
         Hash string into the current state of the hashing object. ``update()``
         can be called any number of times during a hashing object's lifetime.
@@ -232,7 +232,7 @@ class BasePrivateKey(metaclass=ABCMeta):
     @abstractmethod
     def serialize(
         self,
-        passphrase: typing.Optional[typing.ByteString] = None,
+        passphrase: typing.Optional[bytes] = None,
         *args,
         **kwargs,
     ) -> bytes:
@@ -250,7 +250,7 @@ class BasePrivateKey(metaclass=ABCMeta):
     @abstractmethod
     def load(
         cls,
-        passphrase: typing.Optional[typing.ByteString] = None,
+        passphrase: typing.Optional[bytes] = None,
         *args,
         **kwargs,
     ) -> BasePrivateKey:
@@ -258,8 +258,8 @@ class BasePrivateKey(metaclass=ABCMeta):
 
         Args:
             passphrase (bytes):
-                The passphrase to decrypt the private key. Without a passphrase,
-                the key is not encrypted.
+                The passphrase to decrypt the private key. Without a
+                passphrase, the key is not encrypted.
 
         Returns:
             BaseAsymmetricKey: A key object.
