@@ -23,12 +23,13 @@ def supported_modes(backend: _Backends) -> typing.Set[_m]:
 
 def new(
     encrypting: bool,
-    key: typing.ByteString,
+    key: bytes,
     mode: _m,
-    iv_or_nonce: typing.ByteString,
+    iv_or_nonce: bytes,
     *,
     use_hmac: bool = False,
-    digestmod: [str, _base.BaseHash] = "sha256",
+    tag_length: typing.Optional[int] = 16,
+    digestmod: typing.Union[str, _base.BaseHash] = "sha256",
     file: typing.Optional[typing.BinaryIO] = None,
     backend: _Backends = _Backends.CRYPTOGRAPHY,
 ):
@@ -47,28 +48,34 @@ def new(
             repeated with the same key.
 
     Keyword Arguments:
+        use_hmac (bool):
+            Should the cipher use HMAC as authentication or not.
+            (Default: ``False``)
+        tag_length (int, None):
+            Length of HMAC tag. By default, a **16 byte tag** is generated. If
+            ``tag_length`` is ``None``, a **non-truncated** tag is generated.
+            Length of non-truncated tag depends on the digest size of the
+            underlying hash algorithm used by HMAC.
+        digestmod (str, BaseHash):
+            The algorithm to use for HMAC. Defaults to ``sha256``.
+            Specifying this value without setting ``use_hmac`` to True
+            has no effect.
         file (filelike):
             The source file to read from. If ``file`` is specified
             and the ``mode`` is not an AEAD mode, HMAC is always used.
         backend (:class:`pyflocker.ciphers.backends.Backends`):
             The backend to use. It must be a value from :any:`Backends`.
-        hashed (bool):
-            Should the cipher use HMAC as authentication or not.
-            (Default: ``False``)
-        digestmod (str, BaseHash):
-            The algorithm to use for HMAC. Defaults to ``sha256``.
-            Specifying this value without setting ``use_hmac`` to True
-            has no effect.
 
     Important:
         The following arguments are ignored if the mode is an AEAD mode:
 
         - ``use_hmac``
+        - ``tag_length``
         - ``digestmod``
 
     Returns:
         BaseSymmetricCipher:
-            Camellia cipher wrapper from the appropriate backend module.
+            Camellia cipher from the appropriate backend module.
 
     Raises:
         NotImplementedError: if backend does not support that mode.
@@ -84,5 +91,6 @@ def new(
         iv_or_nonce,
         file=file,
         use_hmac=use_hmac,
+        tag_length=tag_length,
         digestmod=digestmod,
     )
